@@ -5,12 +5,13 @@ use std::mem;
 use std::ptr;
 use std::ops::{Deref, DerefMut};
 use std::str;
+use std::str::Utf8Error;
 use std::slice;
 
-use array::Array;
+use array::{Array, ArrayExt};
 use array::Index;
 use CapacityError;
-use char_ext::encode_utf8;
+use odds::char::encode_utf8;
 
 /// A string with a fixed capacity.
 ///
@@ -67,6 +68,23 @@ impl<A: Array<Item=u8>> ArrayString<A> {
         Ok(arraystr)
     }
 
+    /// Create a new `ArrayString` from a byte string literal.
+    ///
+    /// **Errors** if the byte string literal is not valid UTF-8.
+    ///
+    /// ```
+    /// use arrayvec::ArrayString;
+    ///
+    /// let string = ArrayString::from_byte_string(b"hello world").unwrap();
+    /// ```
+    pub fn from_byte_string(b: &A) -> Result<Self, Utf8Error> {
+        let mut arraystr = Self::new();
+        let s = try!(str::from_utf8(b.as_slice()));
+        let _result = arraystr.push_str(s);
+        debug_assert!(_result.is_ok());
+        Ok(arraystr)
+    }
+
     /// Return the capacity of the `ArrayString`.
     ///
     /// ```
